@@ -20,7 +20,7 @@ $D_NOTME     = 0x10; # return received response not for me
 $D_ANSTOP    = 0x20; # clear run OK flag if ANSWER present
 $D_VERBOSE   = 0x40; # verbose debug statements to STDERR
 
-$VERSION = do { my @r = (q$Revision: 0.07 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.08 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK = qw(
         run
@@ -878,6 +878,8 @@ sub bl_lookup {
 =head1 DEPENDENCIES
 
 	Unix::Syslog
+	Geo::IP::PurePerl
+	NetAddr::IP
 	Net::DNS::Codes
 	Net::DNS::ToolKit
 
